@@ -220,21 +220,28 @@ gail_container_real_remove_gtk (GtkContainer       *container,
                                 GtkWidget          *widget,
                                 gpointer           data)
 {
-  AtkPropertyValues values = { 0, };
-  AtkObject* atk_parent = ATK_OBJECT (data);
-  AtkObject *atk_child = gtk_widget_get_accessible (widget);
-  GailContainer *gail_container = GAIL_CONTAINER (atk_parent);
+  AtkPropertyValues values = { NULL };
+  AtkObject* atk_parent;
+  AtkObject *atk_child;
+  GailContainer *gail_container;
   gint       index;
 
-  g_value_init (&values.old_value, G_TYPE_POINTER);
-  g_value_set_pointer (&values.old_value, atk_parent);
-    
-  values.property_name = "accessible-parent";
-  g_object_ref (atk_child);
-  g_signal_emit_by_name (atk_child,
-                         "property_change::accessible-parent", &values, NULL);
-  g_object_unref (atk_child);
+  atk_parent = ATK_OBJECT (data);
+  atk_child = gtk_widget_get_accessible (widget);
 
+  if (atk_child)
+    {
+      g_value_init (&values.old_value, G_TYPE_POINTER);
+      g_value_set_pointer (&values.old_value, atk_parent);
+    
+      values.property_name = "accessible-parent";
+
+      g_object_ref (atk_child);
+      g_signal_emit_by_name (atk_child,
+                             "property_change::accessible-parent", &values, NULL);
+      g_object_unref (atk_child);
+    }
+  gail_container = GAIL_CONTAINER (atk_parent);
   index = g_list_index (gail_container->children, widget);
   g_list_free (gail_container->children);
   gail_container->children = gtk_container_get_children (container);
