@@ -150,11 +150,8 @@ gail_option_menu_get_n_children (AtkObject *obj)
 
   option_menu = GTK_OPTION_MENU (widget);
   if (gtk_option_menu_get_menu (option_menu))
-    {
       n_children++;
-      if (option_menu->menu_item)
-        n_children++;
-    }
+
   return n_children;;
 }
 
@@ -163,10 +160,9 @@ gail_option_menu_ref_child (AtkObject *obj,
                             gint      i)
 {
   GtkWidget *widget;
-  GList *children;
   AtkObject *accessible;
 
-  g_return_val_if_fail (GAIL_IS_OPTION_MENU (obj), 0);
+  g_return_val_if_fail (GAIL_IS_OPTION_MENU (obj), NULL);
 
   widget = GTK_ACCESSIBLE (obj)->widget;
   if (widget == NULL)
@@ -177,18 +173,7 @@ gail_option_menu_ref_child (AtkObject *obj,
 
 
   if (i == 0)
-    accessible = g_object_ref( gtk_widget_get_accessible (gtk_option_menu_get_menu (GTK_OPTION_MENU (widget))));
-  else if (i == 1)
-    {
-      children = gtk_container_get_children (GTK_CONTAINER (widget));
-
-      if (!children)
-        return NULL;
-
-      accessible = gtk_widget_get_accessible (GTK_WIDGET (children->data));
-      g_object_ref (accessible);
-      g_list_free (children);
-    }
+    accessible = g_object_ref (gtk_widget_get_accessible (gtk_option_menu_get_menu (GTK_OPTION_MENU (widget))));
    else
     accessible = NULL;
 
@@ -203,6 +188,8 @@ gail_option_menu_real_add_gtk (GtkContainer *container,
   AtkObject* atk_parent = ATK_OBJECT (data);
   AtkObject* atk_child = gtk_widget_get_accessible (widget);
 
+  GAIL_CONTAINER_CLASS (parent_class)->add_gtk (container, widget, data);
+
   g_object_notify (G_OBJECT (atk_child), "accessible_parent");
 
   g_signal_emit_by_name (atk_parent, "children_changed::add",
@@ -216,16 +203,16 @@ gail_option_menu_real_remove_gtk (GtkContainer *container,
                                   GtkWidget    *widget,
                                   gpointer     data)
 {
-  AtkPropertyValues values = { 0, };
+  AtkPropertyValues values = { NULL };
   AtkObject* atk_parent = ATK_OBJECT (data);
   AtkObject *atk_child = gtk_widget_get_accessible (widget);
 
   g_value_init (&values.old_value, G_TYPE_POINTER);
   g_value_set_pointer (&values.old_value, atk_parent);
 
-  values.property_name = "accessible_parent";
+  values.property_name = "accessible-parent";
   g_signal_emit_by_name (atk_child,
-                         "property_change::accessible_parent", &values, NULL);
+                         "property_change::accessible-parent", &values, NULL);
   g_signal_emit_by_name (atk_parent, "children_changed::remove",
 			 1, atk_child, NULL);
 
